Package: tfrmt
Title: Applies Display Metadata to Analysis Results Datasets
Version: 0.3.0
Authors@R: c(
    person("Becca", "Krouse", , "becca.z.krouse@gsk.com", role = c("aut", "cre")),
    person("Christina", "Fillmore", , "christina.e.fillmore@gsk.com", role = "aut",
           comment = c(ORCID = "0000-0003-0595-2302")),
    person("Ellis", "Hughes", , "ellis.h.hughes@gsk.com", role = "aut",
           comment = c(ORCID = "0000-0003-0637-4436")),
    person("Karima", "Ahmad", , "karima.j.ahmad@gsk.com", role = "aut",
           comment = c(ORCID = "0000-0002-8784-1712")),
    person("Shannon", "Haughton", , "shannon.l.haughton@gsk.com", role = "aut"),
    person("Dragoș", "Moldovan-Grünfeld", , "dragos.v.moldovan-grunfeld@gsk.com", role = "aut"),
    person("Alanah", "Jonas", , "alanah.x.jonas@gsk.com", role = "aut"),
    person("GlaxoSmithKline Research & Development Limited", role = c("cph", "fnd")),
    person("Atorus Research LLC", role = c("cph", "fnd"))
  )
Description: Creates a framework to store and apply display metadata to
    Analysis Results Datasets (ARDs). The use of 'tfrmt' allows users to
    define table format and styling without the data, and later apply the
    format to the data.
License: Apache License (>= 2)
URL: https://GSK-Biostatistics.github.io/tfrmt/,
        https://github.com/GSK-Biostatistics/tfrmt
BugReports: https://github.com/GSK-Biostatistics/tfrmt/issues
Depends: R (>= 4.2.0)
Imports: cli, dplyr, forcats, ggplot2, glue, gt (>= 1.1.0), jsonlite,
        magrittr, purrr, rlang, stringi, stringr (>= 1.6.0), tibble,
        tidyr, tidyselect
Suggests: cards (>= 0.6.0), covr, ggfortify, knitr, patchwork,
        pharmaverseadam, rmarkdown, survival, testthat (>= 3.0.0),
        withr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-23 21:12:06 UTC; bkrouse
Author: Becca Krouse [aut, cre],
  Christina Fillmore [aut] (ORCID:
    <https://orcid.org/0000-0003-0595-2302>),
  Ellis Hughes [aut] (ORCID: <https://orcid.org/0000-0003-0637-4436>),
  Karima Ahmad [aut] (ORCID: <https://orcid.org/0000-0002-8784-1712>),
  Shannon Haughton [aut],
  Dragoș Moldovan-Grünfeld [aut],
  Alanah Jonas [aut],
  GlaxoSmithKline Research & Development Limited [cph, fnd],
  Atorus Research LLC [cph, fnd]
Maintainer: Becca Krouse <becca.z.krouse@gsk.com>
Repository: CRAN
Date/Publication: 2026-01-24 06:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:28:32 UTC; unix
