# Generated by roxygen2: do not edit by hand

S3method(apply_frmt,frmt)
S3method(apply_frmt,frmt_combine)
S3method(apply_frmt,frmt_when)
S3method(as.character,frmt)
S3method(as.character,frmt_combine)
S3method(as.character,frmt_when)
S3method(as.character,span_structure)
S3method(as_json,body_plan)
S3method(as_json,col_plan)
S3method(as_json,col_style_plan)
S3method(as_json,col_style_structure)
S3method(as_json,default)
S3method(as_json,frmt)
S3method(as_json,frmt_combine)
S3method(as_json,frmt_structure)
S3method(as_json,frmt_when)
S3method(as_json,page_plan)
S3method(as_json,quosure)
S3method(as_json,quosures)
S3method(as_json,span_structure)
S3method(as_json,tfrmt)
S3method(as_length_one_quo,character)
S3method(as_length_one_quo,quosure)
S3method(as_length_one_quo,quosures)
S3method(as_vars,character)
S3method(as_vars,quosure)
S3method(as_vars,quosures)
S3method(cleaned_data_to_gt,default)
S3method(cleaned_data_to_gt,list)
S3method(format,body_plan)
S3method(format,frmt)
S3method(format,frmt_combine)
S3method(format,frmt_structure)
S3method(format,frmt_when)
S3method(print,frmt)
S3method(print,frmt_combine)
S3method(print,frmt_structure)
S3method(print,frmt_when)
export("%>%")
export(apply_frmt)
export(as_json)
export(big_n_structure)
export(body_plan)
export(cleaned_data_to_gt)
export(col_plan)
export(col_style_plan)
export(col_style_structure)
export(display_row_frmts)
export(display_val_frmts)
export(element_block)
export(element_row_grp_loc)
export(extract_data)
export(footnote_plan)
export(footnote_structure)
export(frmt)
export(frmt_combine)
export(frmt_structure)
export(frmt_when)
export(is_frmt)
export(is_frmt_combine)
export(is_frmt_structure)
export(is_frmt_when)
export(is_row_grp_structure)
export(json_to_tfrmt)
export(layer_tfrmt)
export(make_mock_data)
export(page_plan)
export(page_structure)
export(param_set)
export(prep_big_n)
export(prep_combine_vars)
export(prep_hierarchical_fill)
export(prep_label)
export(print_mock_gt)
export(print_to_ggplot)
export(print_to_gt)
export(reset_component)
export(row_grp_plan)
export(row_grp_structure)
export(shuffle_card)
export(span_structure)
export(tfrmt)
export(tfrmt_n_pct)
export(tfrmt_sigdig)
export(tfrmt_to_json)
export(update_group)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,cur_column)
importFrom(dplyr,cur_group_id)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,expr)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,group_map)
importFrom(dplyr,group_split)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,lag)
importFrom(dplyr,last)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,na_if)
importFrom(dplyr,pull)
importFrom(dplyr,reframe)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarise)
importFrom(dplyr,tally)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(dplyr,vars)
importFrom(forcats,fct_inorder)
importFrom(ggplot2,.data)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(gt,cell_borders)
importFrom(gt,cell_text)
importFrom(gt,cells_body)
importFrom(gt,cells_column_labels)
importFrom(gt,cells_column_spanners)
importFrom(gt,cells_row_groups)
importFrom(gt,cells_stub)
importFrom(gt,cols_hide)
importFrom(gt,cols_label)
importFrom(gt,default_fonts)
importFrom(gt,gt)
importFrom(gt,gt_group)
importFrom(gt,md)
importFrom(gt,opt_footnote_marks)
importFrom(gt,opt_table_font)
importFrom(gt,px)
importFrom(gt,sub_missing)
importFrom(gt,tab_footnote)
importFrom(gt,tab_header)
importFrom(gt,tab_options)
importFrom(gt,tab_source_note)
importFrom(gt,tab_spanner)
importFrom(gt,tab_stubhead)
importFrom(gt,tab_style)
importFrom(gt,text_transform)
importFrom(jsonlite,parse_json)
importFrom(jsonlite,read_json)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,validate)
importFrom(magrittr,"%>%")
importFrom(purrr,discard)
importFrom(purrr,keep)
importFrom(purrr,list_flatten)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_chr)
importFrom(purrr,map2_dfr)
importFrom(purrr,map2_lgl)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfc)
importFrom(purrr,map_dfr)
importFrom(purrr,map_lgl)
importFrom(purrr,pmap)
importFrom(purrr,pmap_chr)
importFrom(purrr,quietly)
importFrom(purrr,reduce)
importFrom(purrr,safely)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,"f_rhs<-")
importFrom(rlang,`!!`)
importFrom(rlang,`%||%`)
importFrom(rlang,abort)
importFrom(rlang,as_function)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,caller_call)
importFrom(rlang,caller_env)
importFrom(rlang,check_dots_empty0)
importFrom(rlang,eval_bare)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr_text)
importFrom(rlang,f_lhs)
importFrom(rlang,f_rhs)
importFrom(rlang,frame_call)
importFrom(rlang,inform)
importFrom(rlang,is_empty)
importFrom(rlang,is_quosure)
importFrom(rlang,is_quosures)
importFrom(rlang,list2)
importFrom(rlang,parse_expr)
importFrom(rlang,parse_exprs)
importFrom(rlang,quo)
importFrom(rlang,quo_get_expr)
importFrom(rlang,quo_is_missing)
importFrom(rlang,quo_name)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(rlang,warn)
importFrom(stats,as.formula)
importFrom(stats,setNames)
importFrom(stringi,stri_wrap)
importFrom(stringr,str_c)
importFrom(stringr,str_count)
importFrom(stringr,str_detect)
importFrom(stringr,str_dup)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_glue)
importFrom(stringr,str_match)
importFrom(stringr,str_pad)
importFrom(stringr,str_remove)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_trim)
importFrom(stringr,str_which)
importFrom(tibble,add_row)
importFrom(tibble,as_tibble_row)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,crossing)
importFrom(tidyr,expand)
importFrom(tidyr,fill)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,replace_na)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(tidyr,unnest)
importFrom(tidyr,unnest_longer)
importFrom(utils,capture.output)
