# check_order_vars() messages when order variables cause mismatching rows

    Code
      check_order_vars(test_data, tfrmt_plan)
    Message
      Note: Some row labels have values printed over more than 1 line.
       This could be due to incorrect sorting variables. Each row in your output table should have only one sorting var combination assigned to it.

---

    Code
      check_order_vars(test_data2, tfrmt_plan2)
    Message
      Note: Some row labels have values printed over more than 1 line.
       This could be due to incorrect sorting variables. Each row in your output table should have only one sorting var combination assigned to it.

