% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_to_gt.R
\name{cleaned_data_to_gt}
\alias{cleaned_data_to_gt}
\alias{cleaned_data_to_gt.list}
\alias{cleaned_data_to_gt.default}
\title{Do all the formatting for the GT}
\usage{
cleaned_data_to_gt(.data, tfrmt, .unicode_ws)

\method{cleaned_data_to_gt}{list}(.data, tfrmt, .unicode_ws)

\method{cleaned_data_to_gt}{default}(.data, tfrmt, .unicode_ws)
}
\arguments{
\item{.data}{cleaned dataset}

\item{tfrmt}{tfrmt}

\item{.unicode_ws}{Whether to convert white space to unicode in preparation for output}
}
\value{
gt_group object

GT object
}
\description{
Do all the formatting for the GT

Apply formatting to a list of tables

Apply formatting to a single table
}
\keyword{internal}
