% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme_element.R
\name{element_block}
\alias{element_block}
\title{Element block}
\usage{
element_block(post_space = c(NULL, " ", "-"), fill = TRUE)
}
\arguments{
\item{post_space}{Values to show in a new line created after the group block}

\item{fill}{Whether to recycle the value of \code{post_space} to match width of the data. Defaults to \code{TRUE}}
}
\value{
element block object
}
\description{
Element block
}
\examples{

tfrmt_spec <- tfrmt(
  group = grp1,
  label = label,
  param = param,
  value = value,
  column = column,
  row_grp_plan = row_grp_plan(
    row_grp_structure(group_val = ".default", element_block(post_space = "   "))
  ),
  body_plan = body_plan(
    frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
  )
)
}
\seealso{
\code{\link[=row_grp_plan]{row_grp_plan()}} for more details on how to group row group
structures, \code{\link[=row_grp_structure]{row_grp_structure()}} for more details on how to specify row group
structures, \code{\link[=element_row_grp_loc]{element_row_grp_loc()}} for more details on how to
specify whether row group titles span the entire table or collapse.
}
