% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/col_style_plan.R
\name{col_style_plan}
\alias{col_style_plan}
\title{Column Style Plan}
\usage{
col_style_plan(...)
}
\arguments{
\item{...}{series of col_style_structure objects}
}
\value{
col_style_plan object
}
\description{
Define how the columns of the table body should be aligned, whether left,
right or on a specific character(s).
}
\examples{

 plan <- col_style_plan(
    col_style_structure(col = "my_var", align = "left", width = 100),
    col_style_structure(col = vars(four), align = "right"),
    col_style_structure(col = vars(two, three), align = c(".", ",", " "))
   )



}
\seealso{
\code{\link[=col_style_structure]{col_style_structure()}} for more information on how to specify how to and which columns to align.

\href{https://gsk-biostatistics.github.io/tfrmt/articles/col_style_plan.html}{Link to related article}
}
