% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/JSON.R
\name{json_to_tfrmt}
\alias{json_to_tfrmt}
\title{json to tfrmt}
\usage{
json_to_tfrmt(path = NULL, json = NULL)
}
\arguments{
\item{path}{location of the json file to read in}

\item{json}{json object to read in. By default this is null. This function
will read in json object preferentially. So if both a path and a json
object are supplied the json object will be read in.}
}
\description{
Reader to read JSON files/objects into tfrmt objects
}
