% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_efficacy}
\alias{data_efficacy}
\title{Efficacy Analysis Results Data}
\format{
A data frame with 70 rows and 7 variables:
\describe{
\item{group}{highest level row labels}
\item{label}{more specific row labels}
\item{column}{column names}
\item{param}{parameter to explain each value}
\item{value}{values to put in a table}
\item{ord1}{controls ordering}
\item{ord2}{more ordering controls}
}
}
\usage{
data_efficacy
}
\description{
A dataset containing the results needed for an Efficacy table. Using the
CDISC pilot data for ADAS-Cog(11).
}
\keyword{datasets}
