% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tfrmt_layer.R
\name{reset_component}
\alias{reset_component}
\title{Reset or Remove a Component from a tfrmt Object}
\usage{
reset_component(tfrmt_obj, component_name)
}
\arguments{
\item{tfrmt_obj}{A \code{tfrmt} object to be modified.}

\item{component_name}{A character string specifying the name of the component
to reset/remove (e.g., "body_plan").}
}
\value{
A modified \code{tfrmt} object with the specified component removed.
}
\description{
This utility function allows users to remove a specific component (e.g., \code{body_plan},
\code{row_grp_plan}, \code{col_plan}) from a \code{tfrmt} object by setting it to \code{NULL}.
}
\examples{
\dontrun{
  my_tfrmt <- tfrmt(column = "col1", label = "label1")
  # Remove the column component
  reset_tfrmt <- reset_component(my_tfrmt, "column")
}
}
