% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_ae}
\alias{data_ae}
\title{Adverse Events Analysis Results Data}
\format{
A data frame with 2,794 rows and 8 variables:
\describe{
\item{AEBODSYS}{highest level row labels: System Organ Class}
\item{AETERM}{more specific row labels: Preferred Term}
\item{col2}{higher level column names (spanners)}
\item{col1}{lower level column names}
\item{param}{parameter to explain each value}
\item{value}{values to put in a table}
\item{ord1}{controls ordering}
\item{ord2}{more ordering controls}
}
}
\usage{
data_ae
}
\description{
A dataset containing the results needed for an AE table. Using the
CDISC pilot data.
}
\keyword{datasets}
