% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mock_tbl.R
\name{make_mock_data}
\alias{make_mock_data}
\title{Make mock data for display shells}
\usage{
make_mock_data(tfrmt, .default = 1:3, n_cols = NULL)
}
\arguments{
\item{tfrmt}{tfrmt object}

\item{.default}{Number of unique levels to create for group/label values set
to ".default"}

\item{n_cols}{Number of columns in the output table (not including
group/label variables). If not supplied it will default to using the
\code{col_plan} from the \code{tfrmt}. If neither are available it will use 3.}
}
\value{
tibble containing mock data
}
\description{
Make mock data for display shells
}
\examples{

tfrmt_spec <- tfrmt(
  label = label,
  column = column,
  param = param,
  value=value,
  body_plan = body_plan(
    frmt_structure(group_val=".default", label_val=".default", frmt("xx.x"))
    )
  )

make_mock_data(tfrmt_spec)

}
