% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/JSON.R
\name{as_json}
\alias{as_json}
\title{Convert tfrmt elements}
\usage{
as_json(x)
}
\arguments{
\item{x}{tfrmt or tfrmt element}
}
\value{
as_json.tfrmt() will return a json object all other methods will
return a list that is cleaned so it can be directly converted to a json
object
}
\description{
This collection of functions is used to create a json or json ready objects.
While primarily intended for internal use these functions can be used externally
}
\keyword{internal}
