% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_labs}
\alias{data_labs}
\title{Labs Analysis Results Data}
\format{
A data frame with 4,950 rows and 7 variables:
\describe{
\item{group1}{highest level row labels: Lab value class}
\item{group2}{more specific row labels: Lab parameter}
\item{rowlbl}{most specific row labels: Study visit}
\item{col1}{higher level column names (spanners)}
\item{col2}{lower level column names}
\item{param}{parameter to explain each value}
\item{value}{values to put in a table}
\item{ord1}{controls ordering}
\item{ord2}{more ordering controls}
\item{ord3}{more ordering controls}
}
}
\usage{
data_labs
}
\description{
A dataset containing the results needed for an labs results table. Using the
CDISC pilot data.
}
\keyword{datasets}
