% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_demog}
\alias{data_demog}
\title{Demography Analysis Results Data}
\format{
A data frame with 386 rows and 7 variables:
\describe{
\item{rowlbl1}{highest level row labels}
\item{rowlbl2}{more specific row labels}
\item{param}{parameter to explain each value}
\item{grp}{grouping column used to distinguish continuous and categorical}
\item{ord1}{controls ordering}
\item{ord2}{more ordering controls}
\item{column}{column names}
\item{value}{values to put in a table}
}
}
\usage{
data_demog
}
\description{
A dataset containing the results needed for a demography table. Using the
CDISC pilot data.
}
\keyword{datasets}
